@@ -2,7 +2,7 @@
 
 set -ex
 
-if [ $TRAVIS_OS_NAME == linux ]; then
+if [ "$TRAVIS_OS_NAME" == "linux" ]; then
     export CC=${C_COMPILER}
     export CXX=${CXX_COMPILER}
 
@@ -13,11 +13,11 @@ if [ $TRAVIS_OS_NAME == linux ]; then
     sudo update-alternatives --set g++ "/usr/bin/${CXX_COMPILER}"
 fi
 
-if [ $TRAVIS_OS_NAME == linux ]; then
+if [ "$TRAVIS_OS_NAME" == "linux" ]; then
     source /opt/qt${QT_PKG}/bin/qt${QT_PKG}-env.sh || true;
 fi
 
-if [ $TRAVIS_OS_NAME == osx ]; then
+if [ "$TRAVIS_OS_NAME" == "osx" ]; then
     export CMAKE_PREFIX_PATH=/usr/local/opt/qt5
 fi
 
@@ -33,14 +33,14 @@ cmake -GNinja -H. -Bbuild \
     -DCMAKE_INSTALL_PREFIX=.deps/usr
 cmake --build build
 
-if [ $TRAVIS_OS_NAME == osx ]; then
+if [ "$TRAVIS_OS_NAME" == "osx" ]; then
     make lint;
 
-    if [ $DEPLOYMENT == 1 ] && [ ! -z $TRAVIS_TAG ]; then
+    if [ $DEPLOYMENT == 1 ] && [ ! -z $VERSION ] ; then
         make macos-deploy;
     fi
 fi
 
-if [ $TRAVIS_OS_NAME == linux ] && [ $DEPLOYMENT == 1 ] && [ ! -z $TRAVIS_TAG ]; then
+if [ "$TRAVIS_OS_NAME" == "linux" ] && [ $DEPLOYMENT == 1 ] && [ ! -z $VERSION ]; then
     make linux-deploy;
 fi
