@@ -17,6 +17,7 @@
 
 #include <QApplication>
 #include <QLayout>
+#include <QPluginLoader>
 #include <QSettings>
 #include <QShortcut>
 
@@ -58,8 +59,7 @@ MainWindow::MainWindow(QWidget *parent)
 
         restoreWindowSize();
 
-        QFont font("Open Sans");
-        font.setPixelSize(conf::fontSize);
+        QFont font;
         font.setStyleStrategy(QFont::PreferAntialias);
         setFont(font);
 
@@ -113,7 +113,11 @@ MainWindow::MainWindow(QWidget *parent)
 
         connect(
           userSettingsPage_, SIGNAL(trayOptionChanged(bool)), trayIcon_, SLOT(setVisible(bool)));
-
+        connect(userSettingsPage_, &UserSettingsPage::themeChanged, this, []() {
+                Cache::clearUserColors();
+        });
+        connect(
+          userSettingsPage_, &UserSettingsPage::themeChanged, chat_page_, &ChatPage::themeChanged);
         connect(trayIcon_,
                 SIGNAL(activated(QSystemTrayIcon::ActivationReason)),
                 this,
@@ -163,6 +167,10 @@ MainWindow::MainWindow(QWidget *parent)
 
                 showChatPage();
         }
+
+        if (loadJdenticonPlugin()) {
+                nhlog::ui()->info("loaded jdenticon.");
+        }
 }
 
 void
@@ -182,9 +190,10 @@ MainWindow::resizeEvent(QResizeEvent *event)
 void
 MainWindow::adjustSideBars()
 {
-        const uint64_t timelineWidth = chat_page_->timelineWidth();
-        const uint64_t minAvailableWidth =
-          conf::sideBarCollapsePoint + ui::sidebar::CommunitiesSidebarSize;
+        const auto sz = utils::calculateSidebarSizes(QFont{});
+
+        const uint64_t timelineWidth     = chat_page_->timelineWidth();
+        const uint64_t minAvailableWidth = sz.collapsePoint + sz.groups;
 
         if (timelineWidth < minAvailableWidth && !chat_page_->isSideBarExpanded()) {
                 chat_page_->hideSideBars();
@@ -475,3 +484,27 @@ MainWindow::showDialog(QWidget *dialog)
         dialog->raise();
         dialog->show();
 }
+
+bool
+MainWindow::loadJdenticonPlugin()
+{
+        QDir pluginsDir(qApp->applicationDirPath());
+
+        bool plugins = pluginsDir.cd("plugins");
+        if (plugins) {
+                foreach (QString fileName, pluginsDir.entryList(QDir::Files)) {
+                        QPluginLoader pluginLoader(pluginsDir.absoluteFilePath(fileName));
+                        QObject *plugin = pluginLoader.instance();
+                        if (plugin) {
+                                jdenticonInteface_ = qobject_cast<JdenticonInterface *>(plugin);
+                                if (jdenticonInteface_) {
+                                        nhlog::ui()->info("Found jdenticon plugin.");
+                                        return true;
+                                }
+                        }
+                }
+        }
+
+        nhlog::ui()->info("jdenticon plugin not found.");
+        return false;
+}
\ No newline at end of file
