@@ -43,8 +43,7 @@
 
 static constexpr size_t INPUT_HISTORY_SIZE = 127;
 static constexpr int MAX_TEXTINPUT_HEIGHT  = 120;
-static constexpr int InputHeight           = 26;
-static constexpr int ButtonHeight          = 24;
+static constexpr int ButtonHeight          = 22;
 
 FilteredTextEdit::FilteredTextEdit(QWidget *parent)
   : QTextEdit{parent}
@@ -446,14 +445,18 @@ FilteredTextEdit::showPreview(const QMimeData *source, const QStringList &format
 TextInputWidget::TextInputWidget(QWidget *parent)
   : QWidget(parent)
 {
-        setFont(QFont("Emoji One"));
+        QFont f;
+        f.setPointSizeF(f.pointSizeF());
+        const int fontHeight    = QFontMetrics(f).height();
+        const int contentHeight = fontHeight * 2.5;
+        const int InputHeight   = fontHeight * 1.5;
 
-        setFixedHeight(conf::textInput::height);
+        setFixedHeight(contentHeight);
         setCursor(Qt::ArrowCursor);
 
         topLayout_ = new QHBoxLayout();
         topLayout_->setSpacing(0);
-        topLayout_->setContentsMargins(15, 0, 15, 0);
+        topLayout_->setContentsMargins(13, 0, 13, 0);
 
         QIcon send_file_icon;
         send_file_icon.addFile(":/icons/icons/ui/paper-clip-outline.png");
@@ -469,25 +472,25 @@ TextInputWidget::TextInputWidget(QWidget *parent)
         spinner_->setObjectName("FileUploadSpinner");
         spinner_->hide();
 
-        QFont font;
-        font.setPixelSize(conf::textInputFontSize);
-
         input_ = new FilteredTextEdit(this);
         input_->setFixedHeight(InputHeight);
-        input_->setFont(font);
         input_->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
         input_->setPlaceholderText(tr("Write a message..."));
 
-        connect(input_, &FilteredTextEdit::heightChanged, this, [this](int height) {
-                int textInputHeight = std::min(MAX_TEXTINPUT_HEIGHT, std::max(height, InputHeight));
-                int widgetHeight =
-                  std::min(MAX_TEXTINPUT_HEIGHT, std::max(height, conf::textInput::height));
+        connect(input_,
+                &FilteredTextEdit::heightChanged,
+                this,
+                [this, InputHeight, contentHeight](int height) {
+                        int textInputHeight =
+                          std::min(MAX_TEXTINPUT_HEIGHT, std::max(height, InputHeight));
+                        int widgetHeight =
+                          std::min(MAX_TEXTINPUT_HEIGHT, std::max(height, contentHeight));
 
-                setFixedHeight(widgetHeight);
-                input_->setFixedHeight(textInputHeight);
+                        setFixedHeight(widgetHeight);
+                        input_->setFixedHeight(textInputHeight);
 
-                emit heightChanged(widgetHeight);
-        });
+                        emit heightChanged(widgetHeight);
+                });
         connect(input_, &FilteredTextEdit::showSuggestions, this, [this](const QString &q) {
                 if (q.isEmpty() || !cache::client())
                         return;
@@ -556,20 +559,12 @@ TextInputWidget::addSelectedEmoji(const QString &emoji)
 {
         QTextCursor cursor = input_->textCursor();
 
-        QFont emoji_font("Emoji One");
-        emoji_font.setPixelSize(conf::emojiSize);
-
-        QFont text_font("Open Sans");
-        text_font.setPixelSize(conf::fontSize);
-
         QTextCharFormat charfmt;
-        charfmt.setFont(emoji_font);
         input_->setCurrentCharFormat(charfmt);
 
         input_->insertPlainText(emoji);
         cursor.movePosition(QTextCursor::End);
 
-        charfmt.setFont(text_font);
         input_->setCurrentCharFormat(charfmt);
 
         input_->show();
